package MT::Plugin::RelatedCatEntriesByBasename;
use strict;

use MT;
require MT::Plugin;
use MT::Template::Context;
use MT::Util qw(decode_html);

@MT::Plugin::RelatedCatEntriesByBasename::ISA = qw(MT::Plugin);

my $version = "0.1.3";

my $plugin = new MT::Plugin::RelatedCatEntriesByBasename({
	name => 'RelatedCatEntriesByBasename',
	version => $version,
	author_name => 'Junnama Noda',
	author_link => 'http://junnama.alfasado.net/online/',
});

MT->add_plugin($plugin);

use MT::Template::Context;
MT::Template::Context->add_container_tag(RelatedCatEntriesByBasename => \&_RelatedCatEntriesByBasename);
MT::Template::Context->add_conditional_tag(IfRelatedCatByBasename => \&_IfRelatedCatByBasename);
MT::Template::Context->add_conditional_tag(IfRelatedCatEntriesByBasename => \&_IfRelatedCatEntriesByBasename);

sub _RelatedCatEntriesByBasename {
	my ($ctx, $args, $cond) = @_;
	my $tokens = $ctx->stash('tokens');
	my $builder = $ctx->stash('builder');
	my $lastn = $args->{'lastn'};
	unless ($lastn) {
		$lastn = 1000;
	}
	my $order = $args->{'sort_order'};
	unless ($order) {
		$order = 'descend';
	}
	my $entry = $ctx->stash('entry');
	my $blog_id = $entry->blog_id;
	my $basename = $entry->basename;
	my $cat = MT::Category->load({basename => $basename});
	if (defined $cat) {
		my $iter = MT::Entry->load_iter({blog_id => $blog_id,
			status => 2 }, {
			'join' => [ 'MT::Placement', 'entry_id',
			{ blog_id => $blog_id,  category_id => $cat->id,},
			{	sort => 'entry_id',
				direction => $order,
				unique => 1,
				limit => $lastn
			} ],
		});
		my $res = '';
		while (my $entry = $iter->()) {
			local $ctx->{__stash}{'entry'} = $entry;
			defined(my $out = $builder->build($ctx, $tokens, $cond)) or
					return $ctx->error( $builder->errstr );
			$res .= $out;
		}
		$res;
	}
}

sub _IfRelatedCatByBasename {
	my ($ctx, $args, $cond) = @_;
	my $entry = $ctx->stash('entry');
	my $blog_id = $entry->blog_id;
	my $basename = $entry->basename;
	my $cat = MT::Category->load({basename => $basename});
	unless (defined $cat) {
		return 0;
	}
	return 1;
}

sub _IfRelatedCatEntriesByBasename {
	my ($ctx, $args, $cond) = @_;
	my $entry = $ctx->stash('entry');
	my $blog_id = $entry->blog_id;
	my $basename = $entry->basename;
	my $cat = MT::Category->load({basename => $basename});
	unless (defined $cat) {
		return 0;
	} else {
		my $count = MT::Entry->count({blog_id => $blog_id,
			status => 2 }, {
			'join' => [ 'MT::Placement', 'entry_id',
			{ blog_id => $blog_id,  category_id => $cat->id,},
			{	sort => 'entry_id',
				unique => 1
			} ],
		});
		unless ($count) {
			return 0;
		}
	}
	return 1;
}

1;